## Statistic distribution package
In this excercise, i tend to create a package for normal distributions and binomial distribution.
Again this is just an excercise. If you with to add on something else, you are free to.
## Tools needed
- Python IDEL or anaconda software
-  and fwe more
